%-----------------------------------------------------------------------------%
% Copyright (C) 1995-1997, 2000-2001 The University of Melbourne.
% This file may only be copied under the terms of the GNU General
% Public License - see the file COPYING in the Mercury distribution.
%-----------------------------------------------------------------------------%

% File: options.m.
% Main author: fjh.

% This defines the stuff necessary so that getopt.m
% can parse the command-line options.

%-----------------------------------------------------------------------------%

:- module options.
:- interface.
:- import_module bool, string, io, getopt.

:- type option	
	% Verbosity options
		--->	dump_map
		;	dump_stats
		;	curses
		;	dump_packages
		;	dump_plan
		;	dump_all
	% Miscellaneous Options
		;	help.

:- type option_table	==	option_table(option).
		
:- pred short_option(character::in, option::out) is semidet.
:- pred long_option(string::in, option::out) is semidet.
:- pred option_defaults(option::out, option_data::out) is nondet.
:- pred option_default(option::out, option_data::out) is multidet.
:- pred special_handler(option::in, special_data::in,
       option_table::in, maybe_option_table(option)::out) is semidet.

:- pred options_help(io__state::di, io__state::uo) is det.

% A couple of misc utilities

:- pred maybe_write_string(bool::input, string::input,
			io__state::di, io__state::uo) is det.
:- pred maybe_flush_output(bool::in, io__state::di, io__state::uo) is det.

%-----------------------------------------------------------------------------%

:- implementation.
:- import_module std_util, map.

option_defaults(Option, Default) :-
	semidet_succeed,
	option_default(Option, Default).

	% Verbosity Options
option_default(dump_map,	bool(no)).
option_default(dump_plan,	bool(no)).
option_default(dump_packages,	bool(no)).
option_default(dump_stats,	bool(no)).
option_default(curses,		bool(no)).
option_default(dump_all,	special).

	% Miscellaneous Options
option_default(help,		bool(no)).

	% please keep this in alphabetic order
short_option('c',			curses).
short_option('d',			dump_all).
short_option('h', 			help).
short_option('m',			dump_map).
short_option('n',			dump_packages).
short_option('p',			dump_plan).
short_option('s',			dump_stats).

long_option("curses",			curses).
long_option("dump-map",			dump_map).
long_option("dump-plan",		dump_plan).
long_option("dump-packages",		dump_packages).
long_option("dump-stats",		dump_stats).
long_option("dump-all",			dump_all).
long_option("help",			help).

special_handler(dump_all, _, OptionTable0, ok(OptionTable)) :-
	map__set(OptionTable0, dump_map,      bool(yes), OptionTable1),
	map__set(OptionTable1, dump_plan,     bool(yes), OptionTable2),
	map__set(OptionTable2, dump_packages, bool(yes), OptionTable3),
	map__set(OptionTable3, dump_stats,    bool(yes), OptionTable4),
	map__set(OptionTable4, dump_stats,    bool(yes), OptionTable).

options_help -->
	io__write_string("\t-h, --help\n"),
	io__write_string("\t\tPrint this usage message.\n"),

	io__write_string("\nOutput Options:\n"),
	io__write_string("\t-c, --curses\n"),
	io__write_string("\t-d, --dump-all\n"),
	io__write_string("\t-m, --dump-map\n"),
	io__write_string("\t-p, --dump-packages\n"),
	io__write_string("\t-n, --dump-plans\n").

%-----------------------------------------------------------------------------%

maybe_write_string(yes, String) --> io__write_string(String).
maybe_write_string(no, _) --> [].

maybe_flush_output(yes) --> io__flush_output.
maybe_flush_output(no) --> [].

:- end_module options.

%-----------------------------------------------------------------------------%
