:- module test_curs.
:- interface.
:- import_module io.

:- pred main(io__state::di, io__state::uo) is det.

%-----------------------------------------------------------------------------%

:- implementation.
:- import_module curs, game, protocol, list, debug, influence_map.
:- import_module globals, options, getopt, exception.
:- import_module string, list.

main -->
	{ OptionOps = option_ops(short_option, long_option, option_defaults,
				special_handler) },
        { getopt__process_options(OptionOps, ["-d"], _, Result) },
	( { Result = ok(OptionTable) } ->
		globals__io_init(OptionTable)
	;
		{ throw("option handling") }
	),

	io__print("init:\n"),
	io__flush_output,
	init(Game),
	%{ Board = Game^board },
	io__print("init done, starting curses\n"),
	io__flush_output,
	curs__start,
	% curs__clear,
	curs__move(10,10),
	curs__addstr(bold, "testing 1...\n"),
	curs__move(30,30),
	curs__addstr(normal, "testing 3...\n\r"),
	curs__move(20,20),
	curs__addstr(normal, "testing foooo...\n"),
	debug__output_state(Game),
	curs__refresh,
	% main_loop,
	io__see("/dev/tty", _),
	io__read_line(_),
	io__seen,
	curs__stop.

init(Game) -->
	send_init,
	read_board(Board),
	read_config(Config),
	read_server_response(InitialResponse),
	{ Game = init_game(Board, Config, InitialResponse) },
	io__stderr_stream(Stderr),
	io__write_string(Stderr, "finished init\n").

%-----------------------------------------------------------------------------%
main2 -->

    start,
    rows_cols(Rows, Cols),

    move(0, 0),
    addstr(normal, string__format("display size: %dx%d", [i(Rows), i(Cols)])),

    main_loop,

    stop.

% ---------------------------------------------------------------------------- %

:- pred main_loop(io__state, io__state).
:- mode main_loop(di, uo) is det.

main_loop -->

    %doupdate,

    getch(K),

    ( if { K = 0'q       } then []
      else main_loop
    ).
